#[event_loop_event_handler]Expand description
Proc macro which is set on a function that need to be called for every event loop iteration before the server sleeps or after it wakes up. The function must accept a [Context] and [EventLoopSubevent].
#[event_loop_event_handler]Proc macro which is set on a function that need to be called for every event loop iteration before the server sleeps or after it wakes up. The function must accept a [Context] and [EventLoopSubevent].