fork_child_event_handler

Attribute Macro fork_child_event_handler 

#[fork_child_event_handler]
Proc macro which is set on a function that need to be called whenever a fork child event happened. The function must accept a [Context] and [ForkChildSubevent]. Example:

#[fork_child_event_handler]
fn fork_child_event_handler(ctx: &Context, values: ForkChildSubevent) { ... }