#[key_event_handler]Expand description
Proc macro which is set on a function that need to be called whenever a key event happened. The function must accept a [Context] and [KeyEventSubevent]. Example:
ⓘ
#[key_event_handler]
fn key_event_handler(ctx: &Context, values: KeyEventSubevent) { ... }