loading_progress_event_handler

Attribute Macro loading_progress_event_handler 

#[loading_progress_event_handler]
Proc macro which is set on a function that need to be called repeatedly while an RDB or AOF file is being loaded. The function must accept a [Context], [LoadingProgressSubevent], hz: i32 and progress: i32.