swapdb_event_handler

Attribute Macro swapdb_event_handler 

#[swapdb_event_handler]
Proc macro which is set on a function that need to be called whenever a swapdb event happens. The function must accept a [Context] and u64.

Example:

#[swapdb_event_handler]
fn swapdb_event_handler(ctx: &Context, _: u64) { ... }