Proc macro which is set on a function that need to be called whenever a client connects or disconnects on the server.
The function must accept a [Context] and [ClientChangeSubEvent].
This proc macro allow to specify that the follow function is a Valkey command.
The macro accept the following arguments that discribe the command properties:
Proc macro which is set on a function that need to be called whenever a configuration change
event is happening. The function must accept a [Context] and [&&str] that contains the names
of the configiration values that was changed.
Proc macro which is set on a function that need to be called for every
event loop iteration before the server sleeps or after it wakes up.
The function must accept a [Context] and [EventLoopSubevent].
Proc macro which is set on a function that need to be called whenever a flush event happened.
The function must accept a [Context] and [FlushSubevent].
Proc macro which is set on a function that need to be called whenever a fork child event happened.
The function must accept a [Context] and [ForkChildSubevent].
Example:
A procedural macro which registers this function as the custom
INFO command handler. There might be more than one handler, each
adding new information to the context.
Proc macro which is set on a function that need to be called whenever a key event happened.
The function must accept a [Context] and [KeyEventSubevent].
Example:
Proc macro which is set on a function that need to be called whenever a loading event happened.
The function must accept a [Context] and [LoadingSubevent].
Proc macro which is set on a function that need to be called repeatedly
while an RDB or AOF file is being loaded.
The function must accept a [Context], [LoadingProgressSubevent], hz: i32 and progress: i32.
Proc macro which is set on a function that need to be called whenever a master link change event happened.
The function must accept a [Context] and [MasterLinkChangeSubevent].
Example:
Proc macro which is set on a function that need to be called whenever a module is loaded or unloaded on the server.
The function must accept a [Context] and [ModuleChangeSubevent].
Proc macro which is set on a function that need to be called whenever a persistence event happened.
The function must accept a [Context] and [PersistenceSubevent].
Example:
Proc macro which is set on a function that need to be called whenever a
repl-diskless-load config is set to swapdb and a replication with a primary of same data set history occurs.
The function must accept a [Context] and [ReplAsyncLoadSubevent].
Example:
Proc macro which is set on a function that need to be called whenever a replica change event happened.
The function must accept a [Context] and [ReplicaChangeSubevent].
Example:
Implements a corresponding From for this struct, to convert
objects of this struct to an information object to be sent to the
[valkey_module::InfoContext] as a reply.