#[persistence_event_handler]Expand description
Proc macro which is set on a function that need to be called whenever a persistence event happened. The function must accept a [Context] and [PersistenceSubevent]. Example:
ⓘ
#[persistence_event_handler]
fn persistence_event_handler(ctx: &Context, values: PersistenceSubevent) { ... }