#[repl_async_load_event_handler]Expand description
Proc macro which is set on a function that need to be called whenever a repl-diskless-load config is set to swapdb and a replication with a primary of same data set history occurs. The function must accept a [Context] and [ReplAsyncLoadSubevent]. Example:
ⓘ
#[repl_async_load_event_handler]
fn repl_async_load_event_handler(ctx: &Context, values: ReplAsyncLoadSubevent) { ... }