Attribute Macro shutdown_event_handler
Source #[shutdown_event_handler]
Proc macro which is set on a function that need to be called whenever a shutdown event happens.
The function must accept a [Context] and u64.
Example:
ⓘ#[shutdown_event_handler]
fn shutdown_event_handler(ctx: &Context, subevent: u64) { ... }